@@ -3,27 +3,22 @@ import json
 import sys
 from typing import List
 
-from aws_lambda_publish_shared_event.util import build_test_event, list_of_test_events
+from aws_lambda_publish_shared_event.util import build_test_event, handle_list_arguments
 
 
 def parse_args(args: List[str]) -> argparse.Namespace:
     """Parse arguments from the cli"""
-    parser = argparse.ArgumentParser(
-        prog="generate-test-event", description="Generated a local test event to the system out"
-    )
+    parser = argparse.ArgumentParser(prog="generate-test-event", description="Generated a local test event")
     parser.add_argument("-l", "--list", dest="list", help="List of supported event sources", action="store_true")
+    parser.add_argument("--filtered-list", dest="filtered_list", help="Filtered list")
     parser.add_argument("event", help="Event source", nargs="?", default=None)
     return parser.parse_args(args)
 
 
 def main():
     args = parse_args(sys.argv[1:])
-
-    if args.list:
-        print("List of supported event sources:")
-        print(*list_of_test_events(), sep="\n")
-        return
-
+    if handle_list_arguments(args):
+        return True
     event = args.event
     if event is None:
         raise SystemExit("No event source specified")
